## 1.4.0 (2021-05-01)

### Feat

- add Docker support

## 1.3.1 (2021-04-30)

### Fix

- improve logger compatability

## 1.3.0 (2021-04-29)

### Feat

- make exported notes sorted

### Refactor

- add type hints
- dedicate network_retry decorator to store functions

## 1.2.0 (2021-04-28)

### Feat

- add database update routine
- change notes storage mechanism

### Refactor

- move parameters into config

## 1.1.0 (2021-04-27)

### Feat

- add OAuth login option

## 1.0.0 (2021-04-24)

### Feat

- initialize repository
